#
# spec file for package openstack-neutron-fwaas
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define component neutron-fwaas

%define version_unconverted 11.0.0.0b3.dev36

Name:           openstack-%{component}
Version:        11.0.0.0~b3~dev36
Release:        2.2
Summary:        OpenStack Network - firewall as a service
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/neutron
Source:         http://tarballs.openstack.org/%{component}/%{component}-master.tar.gz
Source99:       rpmlintrc
Patch1:         remove-tempest-entry-point.patch
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-neutron
BuildRequires:  openstack-suse-macros
BuildRequires:  python-devel
BuildRequires:  python-pbr
# Documentation build requirements:
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx
# Test requirements
BuildRequires:  python-WebTest >= 2.0
BuildRequires:  python-cliff >= 1.10.0
BuildRequires:  python-fixtures >= 0.3.14
BuildRequires:  python-mock >= 1.0
BuildRequires:  python-neutron-lib
BuildRequires:  python-openstackdocstheme
BuildRequires:  python-oslo.config
BuildRequires:  python-oslotest >= 1.5.1
BuildRequires:  python-psycopg2
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-requests-mock >= 0.6.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 0.9.36
Requires:       openstack-neutron
Requires:       python
Requires:       python >= 2.7
Requires:       python-neutron-fwaas = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Neutron is a virtual network service for Openstack.

Just like OpenStack Nova provides an API to dynamically request and
configure virtual servers, Neutron provides an API to dynamically
request and configure virtual networks. These networks connect
"interfaces" from other OpenStack services (e.g., vNICs from Nova VMs).
The Neutron API supports extensions to provide advanced network
capabilities (e.g., QoS, ACLs, network monitoring, etc)

This package contains the firewall as as service (fwaas) component for Neutron.

%package -n python-%{component}
Summary:        OpenStack Network fwaas - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.7
Requires:       python-SQLAlchemy >= 1.0.10
Requires:       python-alembic >= 0.8.10
Requires:       python-eventlet >= 0.18.2
Requires:       python-httplib2 >= 0.7.5
Requires:       python-netaddr >= 0.7.13
Requires:       python-neutron-lib >= 1.9.0
Requires:       python-oslo.concurrency >= 3.8.0
Requires:       python-oslo.config >= 4.0.0
Requires:       python-oslo.db >= 4.24.0
Requires:       python-oslo.log >= 3.22.0
Requires:       python-oslo.messaging >= 5.24.2
Requires:       python-oslo.privsep >= 1.9.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.service >= 1.10.0
Requires:       python-oslo.utils >= 3.20.0
Requires:       python-pbr >= 2.0.0
Requires:       python-pyroute2 >= 0.4.17
Requires:       python-six >= 1.9.0

%description -n python-%{component}
This package contains the core Python module of OpenStack Neutron fwaas


%package test
Summary:        OpenStack Network fwaas - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-WebOb >= 1.7.1
Requires:       python-testresources >= 0.2.4

%description test
The OpenStack Neutron fwaas testsuite. It is used to verify the functionality
of OpenStack Neutron.


%prep
%setup -q -n %{component}-%{version_unconverted}
%patch1 -p1

%openstack_cleanup_prep

%build
python setup.py build
python setup.py build_sphinx -b man

for x in `ls etc/oslo-config-generator/*`; do
    PYTHONPATH=. oslo-config-generator --config-file $x
done

%install
python setup.py install --skip-build --prefix=%{_prefix} --root=%{buildroot} --install-data=/

### configuration files
install -p -D -m 644 etc/fwaas_driver.ini.sample %{buildroot}%{_sysconfdir}/neutron/fwaas_driver.ini

## SUSE configuration defaults
crudini --set %{buildroot}/etc/neutron/fwaas_driver.ini fwaas driver neutron_fwaas.services.firewall.drivers.linux.iptables_fwaas.IptablesFwaasDriver
crudini --set %{buildroot}/etc/neutron/fwaas_driver.ini fwaas enabled True

### misc
%fdupes %{buildroot}%{python_sitelib}/neutron_fwaas

%check
testr init
###
#testr list-tests

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%config(noreplace) %{_sysconfdir}/neutron/fwaas_driver.ini
%config(noreplace) %{_sysconfdir}/neutron/rootwrap.d/fwaas-privsep.filters

%files -n python-%{component}
%defattr(-,root,root,-)
%doc LICENSE
%{python_sitelib}/neutron_fwaas/
%{python_sitelib}/*.egg-info
%exclude %{python_sitelib}/neutron_fwaas/tests/

%changelog
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev36:
  * Use API Definitions from neutron-lib
* Thu Jul 27 2017 tbechtold@suse.com
- Update to version neutron-fwaas-11.0.0.0b3.dev35:
  * Handle rehome of firewall exceptions
  * Updated from global requirements
  * Move remaining policy rules specific to neutron-fwaas
  * rearrange content to fit the new standard layout
  * Switch from oslosphinx to openstackdocstheme
  * Enable warning-is-error in doc build
* Tue Jul 11 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev24:
  * Use flake8-import-order plugin
* Sat Jul  8 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev22:
  * Updated from global requirements
* Tue Jul  4 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev21:
  * use plugin constants from neutron-lib
* Sat Jul  1 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev19:
  * use service type constants from neutron\_lib plugins
  * Replace the usage of 'manager' with 'os\_primary'
  * Enable to set neutron's local repository for testing
* Fri Jun 30 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev14:
  * Updated from global requirements
  * Improve iptables handling
* Wed Jun 28 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev11:
  * Revert "Use neutron-lib definition of neutron-fwaas API"
* Fri Jun 23 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev10:
  * Add original copyright
* Wed Jun 21 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev8:
  * Refactor find iptables rules
  * Updated from global requirements
* Wed Jun 14 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b3.dev4:
  * Updated from global requirements
  * Trivial-fix: Remove non ascii char
  11.0.0.0b2
  * Fixed comments in tox.ini [flake8]
  * Optimize the link address
  * Modify an order between iptables and conntrack when update firewall
* Wed Jun  7 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev37:
  * Migrate Neutron's attribute to Neutron-Lib
  * Use neutron-lib definition of neutron-fwaas API
  * Fix html\_last\_updated\_fmt for Python3
  * Replace assertRaisesRegexp with assertRaisesRegex
  * Updated from global requirements
  * Added neutron\_fwaas.conf file for Firewall config
* Fri May 26 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev25:
  * Updated from global requirements
* Wed May 24 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev24:
  * tox\_install: speed up neutron repo clone
* Sat May 20 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev23:
  * Updated from global requirements
* Fri May 19 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev22:
  * devstack: Adapt to lib/neutron
* Thu May 18 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev21:
  * Updated from global requirements
* Thu May 11 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev20:
  * Updated from global requirements
* Thu May  4 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev19:
  * Remove get\_namespace from API extensions
* Sat Apr 29 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev17:
  * Updated from global requirements
  * Add supported conntrack\_driver option to devstack plugin
  * consume neutron-lib callbacks
  * Use \_i18n in unittests
  * Remove unused get\_firewalls\_for\_tenant\_without\_rules
  * Switch to use stable data\_utils
  * Convert gate\_hook to devstack-tools
  * Fix scale issue in case of services\_sync\_needed v1
  * Optimize get\_firewalls\_for\_tenant implementation
  * Define in\_namespace contextmanager
  * gate\_hook: Stop including localrc
  * Switch to use test\_utils.call\_until\_true
  * Do not complain in firewall\_group\_deleted if the FW is already deleted
  * Do not complain in firewall\_deleted if the FW is already deleted
  * Correct LOG message in fwaas\_plugin\_v2
  * Switch to decorators.idempotent\_id
  * Optimize \_make\_firewall\_group\_dict\_with\_rules
  * Optimize \_make\_firewall\_dict\_with\_rules db queries
  * Fix 'ports' attribute for firewall\_group
  * Fix AssertionError raised from \_set\_rules\_for\_policy
  * Use BRANCH constants from neutron\_lib
  * Consistent update with router\_info
  * Fix PENDING\_UPDATE state when update exist no policy fw\_group with ports
  * Not allow to update icmp fw\_rule with port
  * Fix removing rule\_association on updating a policy
  * Use DB field sizes instead of \_MAX\_LEN constants
  * Revert "Set NETWORK\_API\_EXTENSIONS in fwaas devstack plugin"
  * Set NETWORK\_API\_EXTENSIONS in fwaas devstack plugin
  * Replaces uuid.uuid4 with uuidutils.generate\_uuid()
  * Fix fwaas\_v2 driver internal error when restart l3 agent
  * Refactor of \_convert\_fwaas\_to\_iptables\_rule and dependencies
  * Fix import path for l3\_config
  * gate\_hook: Fix INSTALL\_MYSQL\_ONLY != True case
  * Check for \_interfaces in updated\_router
  * Fix neutron-fwaas tests after project\_id addition
  * Skip test test\_update\_firewall\_shared\_fails\_for\_non\_admin
  * Use neutron-lib model\_base instead of neutron models
  * TrivialFix: Add validation for tenant\_id
  * Fix column\_name in migration from project\_id change
  * Fix db migration after project\_id changes
  * Fix a few test cases in test\_cisco\_fwaas\_plugin
  * Remove check\_i18n files
  * Use call\_and\_ignore\_notfound\_exc directly
  * Fix neutron\_lib deprecations
  * FWaaS Disable nonstandard-exception due to neutron\_lib shims
  * FWaaS: make use of neutron\_lib constants
  * FWaaS: make use of neutron\_lib exceptions
  * tempest: Skips router insertion tests if public\_router\_id is configured
  * Add an explicit BRANCH\_NAME to tox\_install.sh
  * Add unittest of convert\_action\_to\_case\_insensitive
  * Add unit test for convert\_protocol
  * Fix a typo from UPPER\_CONTRAINTS\_FILE to UPPER\_CONSTRAINTS\_FILE
  * Validation of router\_ids insertion with column selection
  * Set ZUUL\_BRANCH using BRANCH if not available
  * Remove deprecated use\_namespaces option
  * Prepare neutron "use\_namespaces" option removal
  * Removed new=True argument from create\_connection
  * Validate src\_ip\_adress, dest\_ip\_address and ip\_version
  * use assertFalse instead of assertEqual(False, \*\*\*)
  * Change ignore-errors to ignore\_errors
  * Fix check\_migration error
  * Validate tenant\_id between firewall and firewall-policy
  * Do not make delete\_db\_firewall conditional
  * Register alembic\_migrations at install time
  * Fix wrong argument name in \_rpc\_update\_firewall
  * Use oslo\_log.helpers.log\_method\_call
  * COMMON\_PREFIXES cleanup - patch 3/5
  * Switch to oslo\_utils.uuidutils
  * Revert "Insert tenant\_id validation for fw and fw-policy"
  * Add validation of port\_range for firewall-rule
  * Insert tenant\_id validation for fw and fw-policy
  * Switch from neutron.common.log.log to oslo\_log.helpers.log\_method\_call
  * Remove reference to testlib\_plugin
  * Add the missing parameter agent\_mode to the FWaaSDriverBase class methods
  * Add the prefix networking\_brocade to import paths
  * Pick up missing neutron to neuton\_fwaas change
  * Enable removing references to self.services\_sync in l3 agent
  * Stop storing and passing root\_helper
  * Fix pylint error due to novaclient v1\_1/v2 rename
  * Add index on tenant\_id
  * Remove unused \_destroy\_router\_namespaces()
  * Pass root\_helper to ip\_lib by keyword argument to prep for removal
  * Fixed tests to use neutron\_fwaas extensions and neutrons
  * Move '\_make\_firewall\_dict\_with\_rules' to firewall\_db.py
  * Move classes out of l3\_agent.py
  * Fix python path to neutron\_fwaas module
  * pretty\_tox.sh: Portablity improvement
  * test\_dhcp\_agent: Fix no-op tests
  * Fix incorrect exception order in \_execute\_request
  * Remove duplicate ensure\_remove\_chain method in iptables\_manager
  * Remove use\_namespaces from RouterInfo Property
  * Switch run-time import to using importutils.import\_module
  * mock.assert\_called\_once() is not a valid method
  * Remove useless check in \_rpc\_update\_firewall
  * Add requests\_mock to test-requirements.txt
  * Supply missing cisco\_cfg\_agent.ini file
  * Remove unused arg to config.setup\_logging()
  * Remove SELECT FOR UPDATE use in delete\_firewall
  * Remove reference to cisco\_cfg\_agent.ini from setup.cfg again
  * Fix state\_path in tests
  * Remove SELECT FOR UPDATE use in update\_firewall
  * Remove status initialization from plugin's create\_firewall
  * Remove reference to cisco\_cfg\_agent.ini from setup.cfg
  * This patch changes the name of directory from mech\_arista to arista
  * Allow to import \_LC, \_LE, \_LI and \_LW functions directly
  * Use auth\_token from keystonemiddleware
  * Change all occurences of no\_delete to do\_delete
  * Remove reference to setuptools\_git
  * Moved rpc\_compat.py code back into rpc.py
  * Removed create\_rpc\_dispatcher methods
  * Renamed consume\_in\_thread -> consume\_in\_threads
  * Added missing core\_plugins symbolic names
  * Introduced rpc\_compat.create\_connection()
  * Set ns\_name in RouterInfo as attribute
  * Fix KeyError except on router\_info in FW Agent
  * Bugfix and refactoring for ovs\_lib flow methods
  * ipt\_mgr.ipv6 written in the wrong ipt\_mgr.ipv4
  * Validate rule uuids provided for update\_policy
  * Rename check\_nvp\_config utility tool
  * Corrects broken format strings in check\_i18n.py
  * Add fwaas\_driver.ini to setup.cfg
  * Ensure get\_pid\_to\_kill works with rootwrap script
  * Call \_destroy\_metadata\_proxy from \_destroy\_router\_namespaces
  * Fix import log\_handler error with publish\_errors set
  * Fix to enable delete of firewall in PENDING\_CREATE state
  * Install metering\_agent.ini and vpn\_agent.ini
  * Enclose command args in with\_venv.sh
  * Ignore pbr\*.egg directory
  * Sync install\_venv\_common from oslo
  * Rename agent\_loadbalancer directory to loadbalancer
  * Add \*.swo/swp to .gitignore
  * Revert "Fix ./run\_tests.sh --pep8"
  * Fix ./run\_tests.sh --pep8
  * Add lbaas\_agent files to setup.py
  * Add VIRTUAL\_ENV key to enviroment passed to patch\_tox\_env
  * Sync latest install\_venv\_common.py with olso
  * Allow tools/install\_venv\_common.py to be run from within the source directory
  * Use install\_venv\_common.py from oslo
  * Add restproxy.ini to config\_path in setup.py
  * Add metadata\_agent.ini to config\_path in setup.py
  * Remove \_\_init\_\_.py from bin/ and tools/
  * Use auth\_token middleware in keystoneclient
  * Add QUANTUM\_ prefix for env used by quantum-debug
  * Add eventlet\_backdoor and threadgroup from openstack-common
  * l3\_nat\_agent was renamed to l3\_agent and this was missed
  * Add build\_sphinx options
  * Change Resource.\_\_call\_\_() to not leak internal errors
  * Add code-coverage support to run\_tests.sh (lp860160)
  * Introducting cheetah Updating list\_nets in CLI Writing unit tests for list\_nets Stubbing out with FakeConnection now
  * force batch\_config.py to use json, as XML has issues (see bug: 798262)
  * update batch\_config.py to use new client lib, hooray for deleting code
  * persistence of l2network & ucs plugins using mysql - db\_conn.ini - configuration details of making a connection to the database - db\_test\_plugin.py - contains abstraction methods for storing database values in a dict and unit test cases for DB testing - l2network\_db.py - db methods for l2network models - l2network\_models.py - class definitions for the l2 network tables - ucs\_db.py - db methods for ucs models - ucs\_models.py - class definition for the ucs tables dynamic loading of the 2nd layer plugin db's based on passed arguments Create, Delete, Get, Getall, Update database methods at - Quantum, L2Network and Ucs Unit test cases for create, delete, getall and update operations for L2Network and Ucs plugins pep8 checks done branch based off revision 34 plugin-framework
  * merged the latest changes from plugin-framework branch - revision 39 conforming to the new cisco plugin directory structure and moving all db related modules into cisco/db folder updated db\_test\_plugin.py  - added import of cisco constants module  - added LOG.getLogger for logging component name  - updated import module paths for l2network\_models/db and ucs\_models/db to use the new directory structure  - updated (rearranged) imports section to obey openstack alphabetical placement convention updated db\_conn.ini  - updated database name from cisco\_naas to quantum\_l2network unit test cases ran successfully and pep8 checks done again
  * fix bug 817826 and similar error in batch\_config.py
  * refactor batch\_config, allow multiple attaches with the empty string
  * Merging latest changes from parent repo - lp:network-service , Parent repo had approved merge proposal for merging lp:~santhom/network-service/quantum\_testing\_framework , which has now been merged into lp:network-service
  * Merging pep8 and functional test related changes lp:~santhom/network-service/quantum\_testing\_framework branch
  * add example to usage string for batch\_config.py
* Thu Apr 20 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev12:
  * Remove unused 'host' parameter from Unit tests
  * ConntrackNetlink driver to delete conntrack entries
  * Disable new N537 hacking check from next neutron-lib
* Tue Apr 18 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev7:
  * Updated from global requirements
  * Remove subunit-trace fork
  * Adding cleanup of router in unit tests
  * Optimize fwaas tempest api tests
* Sat Apr 15 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-11.0.0.0b2.dev2:
  * Migrate Public attribute to shared in Policy.json
  11.0.0.0b1
* Fri Apr 14 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev75:
  * Netlink library to delete conntrack entries
* Tue Apr 11 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev74:
  * Added 'shared' attribute for firewall resources
* Thu Apr  6 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev72:
  * Use _i18n in unittests
  * Enable to configure conntrack driver
  * Add blank line under the subject
  * Optimize the link address for fetching git code
* Tue Apr  4 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev64:
  * Updated from global requirements
* Fri Mar 31 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev63:
  * Rehome L3 exceptions to neutron-lib
* Thu Mar 30 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev61:
  * Remove pyroute2.netns.setns patch
  * Remove unused get_firewalls_for_tenant_without_rules
  * Remove "plugins" directory
* Thu Mar 23 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev55:
  * Updated from global requirements
* Wed Mar 22 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev54:
  * Remove duplicate SQL request on firewall update
  * Fix some unit test comments
* Tue Mar 21 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev50:
  * Revert "Revert "Fix RPC scale issue using cast instead of fanout v1""
  * Cleanup setUp method in Unit tests
  * Remove support for py34
* Wed Mar 15 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev44:
  * Switch to use stable data_utils
  * tempest: Switch to local copy of tempset/scenario/manager.py
* Tue Mar 14 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev41:
  * Updated from global requirements
* Fri Mar 10 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev40:
  * Convert gate_hook to devstack-tools
  * Revert "Fix RPC scale issue using cast instead of fanout v1"
  * Fix RPC scale issue using cast instead of fanout v1
  * Use neutron-lib's context module instead of neutron
  * Updated from global requirements
  * Optimize get_firewalls_for_tenant implementation
  * Define in_namespace contextmanager
  * Enable to run rootwrap/privsep related functional tests
* Sat Mar  4 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev26:
  * consume ServicePluginBase from neutron-lib
  * Fix scale issue in case of services_sync_needed v1
  * Use lazy formatting when logging
  * [Fix gate]Update test requirement
  * Updated from global requirements
  * Remove "constants" duplicated import
* Wed Mar  1 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev18:
  * Updated from global requirements
* Tue Feb 28 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev17:
  * gate_hook: Stop including localrc
* Tue Feb 21 2017 tbechtold@suse.com
- Adjust Requires
* Mon Feb 20 2017 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0rc2.dev16:
  * Revert "Netlink solution to improve FWaaS performance"
* Thu Feb 16 2017 nicolas.bock@suse.com
- Update to version neutron-fwaas-10.0.0.0rc2.dev14:
  * Cleanup useful code in unit tests
  * Updated from global requirements
  * Switch to use test_utils.call_until_true
  * Fix typo in .pylintrc file
  * Do not complain in firewall_group_deleted if the FW is already deleted
  * Add functional test to run dsvm-functional
  * Do not complain in firewall_deleted if the FW is already deleted
  * Correct LOG message in fwaas_plugin_v2
  * Update reno for stable/ocata
- 10.0.0.0rc1
  * Use addCleanup instead of tearDown
  * Switch to decorators.idempotent_id
  * TrivialFix: Added link for modindex
  * Optimize _make_firewall_group_dict_with_rules
- 10.0.0.0b3
  * Update policy.json for FWaaS v2
  * Updated from global requirements
  * Netlink solution to improve FWaaS performance
  * Fix validation in converting 'protocol'
  * Fix tempest gate issue on FirewallNotFound exception
  * Optimize _make_firewall_dict_with_rules db queries
  * Updated from global requirements
  * Fix 'ports' attribute for firewall_group
  * TrivialFix : Fix Port Error Message
  * Fix AssertionError raised from _set_rules_for_policy
  * Use BRANCH constants from neutron_lib
  * Fix duplicated python version in classifier
  * Track neutron-lib migration of agent extensions
  * Support neutron-lib hacking check H904
  * Updated from global requirements
  * [WIP]Remove no used attribute in FirewallPolicyRuleAssociation
  * Fix update fwr with ipv6 address
  * Consistent update with router_info
  * Fix a typo
  * Remove httplib2 useless requirement
  * Updated from global requirements
  * Enable coverage report in console output
  * Check error message returned by the system
  * Fix PENDING_UPDATE state when update exist no policy fw_group with ports
  * Privsep configuration for neutron-fwaas
* Sat Dec 24 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b3.dev7:
  * Not allow to update icmp fw_rule with port
* Fri Dec 23 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b3.dev5:
  * Updated from global requirements
* Fri Dec 16 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b3.dev4:
  * Use neutron-lib and fwaas constants instead of neutron
  10.0.0.0b2
  * neutron-lib cleanup in neutron-fwaas
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev29:
  * Updated from global requirements
  * Tempest Scenario tests for FWaaS V2
* Wed Dec 14 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev26:
  * Docs: fix Devstack config documentation rendering
  * Changed the home-page link
  * Adding validation protocol parameters when updating firewall rules
* Thu Dec  1 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev21:
  * Updated from global requirements
  * Show team and repo badges on README
  * Use TimeoutException from tempest.lib
* Wed Nov 30 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev16:
  * Fix removing rule_association on updating a policy
  * Add os-testr to test requirements
* Tue Nov 29 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev13:
  * Use ExtensionDescriptor from neutron-lib
  * Reenable FWaaS v2 tempest tests
* Mon Nov 28 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev10:
  * Use DB field sizes instead of _MAX_LEN constants
  * Remove PLURALS
  * Validation of router_ids insertion with column selection
* Thu Nov 24 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev7:
  * Switch to using plugins directory in lieu of neutron manager
* Wed Nov 23 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev5:
  * Add a variant of gate hook script
  * Revert "Set NETWORK_API_EXTENSIONS in fwaas devstack plugin"
  * FWaaS v2 Tempest API tests
* Mon Nov 21 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-10.0.0.0b2.dev2:
  * Set NETWORK_API_EXTENSIONS in fwaas devstack plugin
  10.0.0.0b1
* Wed Nov 16 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev51:
  * Updated from global requirements
  * Updated from global requirements
* Tue Nov 15 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev49:
  * Replaces uuid.uuid4 with uuidutils.generate_uuid()
  * Add smoke tests to neutron-fwaas
  * Add Python 3.5 classifier and venv
* Mon Nov 14 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev43:
  * Add developer documentation to FWaaS
* Sat Nov 12 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev41:
  * Remove unused code
* Wed Nov  9 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev40:
  * Fix fwaas_v2 driver internal error when restart l3 agent
* Tue Nov  8 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev38:
  * Updated from global requirements
* Sat Nov  5 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev37:
  * Remove last vestiges of oslo-incubator
* Thu Nov  3 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev36:
  * Updated from global requirements
* Wed Nov  2 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev35:
  * Remove unnecessary neutron agent config reference
  * Remove import of neutron.extensions
* Fri Oct 28 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev32:
  * Updated from global requirements
* Tue Oct 25 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev31:
  * Catch the integrityError when update firewall group with non exist port
* Sat Oct 22 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev30:
  * Updated from global requirements
* Fri Oct 21 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev29:
  * Migrate references from neutron to neutron-lib
* Thu Oct 20 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev28:
  * Fix UnboundLocalError during update firewall group
* Wed Oct 19 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev26:
  * Fix typo in comment
* Tue Oct 18 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev25:
  * Refactor of _convert_fwaas_to_iptables_rule and dependencies
* Fri Oct 14 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev24:
  * Updated from global requirements
* Thu Oct 13 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev23:
  * Deal with the '-m protocol' flag in iptables FwAAS v1 and v2
* Sat Oct  8 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev22:
  * Fix periodic-neutron-fwaas-pyXX-with-neutron-lib-master jobs
* Fri Oct  7 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev20:
  * Enable release notes translation
* Thu Oct  6 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev19:
  * Fix an argument for an exception message
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev17:
  * Updated from global requirements
* Wed Sep 28 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev16:
  * Remove reference to third-party drivers in readme
  * Fix import path for l3_config
  * Updated from global requirements
* Tue Sep 27 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev11:
  * Updated from global requirements
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev10:
  * Add devstack plugin support for fwaas v2
  * gate_hook: Fix INSTALL_MYSQL_ONLY != True case
  * Fix KeyError when fw rule associated with a policy is updated
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev5:
  * Updated from global requirements
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0rc2.dev4:
  * Check for _interfaces in updated_router
  * Add neutron-fwaas in-tree documentation
  * Update reno for stable/newton
  9.0.0.0rc1
* Thu Sep 15 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0b4.dev9:
  * Tag the alembic migration revisions for Newton
  * Updated from global requirements
  * Add reno note for FWaaS v2
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0b4.dev4:
  * Fix neutron-fwaas tests after project_id addition
* Tue Sep 13 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0b4.dev3:
  * Skip test test_update_firewall_shared_fails_for_non_admin
* Wed Sep  7 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-9.0.0.0b4.dev2:
  * Migrate FWaaS policy.json to FWaaS repo
* Fri Sep  2 2016 tbechtold@suse.com
- Update to version neutron-fwaas-9.0.0.0b4.dev1:
  * Updated from global requirements
  9.0.0.0b3
  * Add tests ensuring models and migrations are in sync
  * FWaaS v2 utilize L3 Agent Extension framework
  * Use neutron-lib model_base instead of neutron models
  * Add FWaaS v1 and v2 entrypoints to setup.cfg
  * Add special handling for functional tests
  * Remove vendor driver: vyatta from community repo
  * Use temporary directory for neutron install
  * Remove Cisco driver from neutron-fwaas repo
  * Updated from global requirements
  * FWaaS v2 Database rule insert/remove operations support
  * Remove vendor driver: vArmour from community repo
  * FWaaS v2 L3 Agent Extension
  * FWaaS V2 Plugin
  * Fix enum usage in db migration for postgresql
  * Fix db vs migration mismatches
  * Fix db migration chain
  * Fix model/migration sync issues with FWaaS
  * Updated from global requirements
  * Constrain remaining tox targets
  * FWaaS v2 Database
  * TrivialFix: Add validation for tenant_id
  * FwaaS v2 REST API
  * Fix column_name in migration from project_id change
  * Fix db migration after project_id changes
  * Remove temporary local HasProject
  * Enable DeprecationWarning in test environments
  * Updating imports as l3 agent config options
  * Updated from global requirements
  * devstack: Don't bother to have our own l3 agent config file
  * Update imports (common.config -> conf.common)
  * Rename DB columns: tenant -> project
* Fri Jul 15 2016 opensuse-packaging@opensuse.org
- Rebased patches:
  + remove-tempest-entry-point.patch (manually)
* Fri Jul 15 2016 aplanas@suse.de
- Update to version neutron-fwaas-9.0.0.0b3.dev3:
  * add "reject" action to firewall rule doesn't work for postgresql
  * Updated from global requirements
  9.0.0.0b2
  * Delete mcafee FwaaS driver
  * Updated from global requirements
  * DevStack plugin for fwaas
  * Add python 3 classifiers
  * Add entrypoints for iptables and varmor drivers
  * Fix deprecation warnings
  * Fix subunit trace help
  * Fix a few test cases in test_cisco_fwaas_plugin
  * Follow the recent tempest change
  * Remove unused POT file
  * Updated from global requirements
  * Remove check_i18n files
  * Use call_and_ignore_notfound_exc directly
  * Updated from global requirements
  9.0.0.0b1
  * Fix neutron_lib deprecations
  * [Trivial] Remove unnecessary executable privilege
  * Remove unnecessary executable permissions
  * Updated from global requirements
  * Fix broken tempest tests
  * Skip broken tests
  * Switch to using hacking checks from neutron-lib
  8.1.2
  * Updated from global requirements
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.1.dev9:
  * Fix "Not applying Firewall rules immediately" problem
* Wed Apr 20 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.1.dev8:
  * Updated from global requirements
* Tue Apr 19 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.1.dev7:
  * Don't use zuul-cloner for venv env, for periodic jobs
  * Fix doc build if git is absent
  * FWaaS Disable nonstandard-exception due to neutron_lib shims
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.1.dev2:
  * Updated from global requirements
  * Arista ML2 Mechanism driver
  * Copy the RHEL6 eventlet workaround from Oslo
  * fix bug lp:1025526,update iniparser.py to accept  empty value
  * merged the latest changes from plugin-framework branch - revision 39 conforming to the new cisco plugin directory structure and moving all db related modules into cisco/db folder updated db_test_plugin.py  - added import of cisco constants module  - added LOG.getLogger for logging component name  - updated import module paths for l2network_models/db and ucs_models/db to use the new directory structure  - updated (rearranged) imports section to obey openstack alphabetical placement convention updated db_conn.ini  - updated database name from cisco_naas to quantum_l2network unit test cases ran successfully and pep8 checks done again
  * merge Salvatore's api branch with fixes for tests.  Tweaking branch to remove unwanted bin/quantum.py as part of merge
  * Merging pep8 and functional test related changes lp:~santhom/network-service/quantum_testing_framework branch
* Sat Apr  9 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.1.dev1:
  8.0.0
  * Constraint requirements using mitaka upper-constraints.txt file
  8.0.0.0rc2
  * Update .gitreview for stable/mitaka
* Wed Mar 23 2016 tbechtold@suse.com
- Add remove-tempest-entry-point.patch
  Don't run fwaas tempest tests for now. There's is no mechanism
  in tempest to skip tests from a plugin so remove the entry point.
* Wed Mar 23 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0rc2.dev3:
  * Translations: add in the locale directory
* Fri Mar 18 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0rc2.dev2:
  * FWaaS: make use of neutron_lib exceptions
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0rc2.dev1:
  * Update reno for stable/mitaka
  8.0.0.0rc1
* Wed Mar 16 2016 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0b4.dev8:
  * Fixed typo in subunit-trace.py
* Mon Mar 14 2016 tbechtold@suse.com
- Update to version neutron-fwaas-8.0.0.0b4.dev7:
  * Use routers client instead of networks client
  * Use tempest.lib base module for network
  * Updated from global requirements
  * Make all tox targets constrained
  * Tag the alembic migration revisions for Mitaka
  8.0.0.0b3
  * FWaaS: make use of neutron_lib constants
  * Use tempest.lib instead of tempest-lib
  * Track alembic heads
  * Remove unused pngmath Sphinx extension
  * Updated from global requirements
  * Select the right DB to store user and data in each backend
  * Modify tox.ini to run dsvm-functional tests
  * Updated from global requirements
  * delete meaningless braces in log
  * Updated from global requirements
  * Cleanup i18n module usages
  * tempest: Confirm the opposite direction
  * tempest: Fix a few test cases
  * FWaaS quota registration
  * Add testresources to neutron-fwaas test requirements
  * Fix neutron-fwaas cover tests
  * Send Notifications for Firewall policy updates
  * Set testenv env for api and scenario testing
  * tempest: Skips router insertion tests if public_router_id is configured
  * tempest: Update for NetworkClient
  * Add an explicit BRANCH_NAME to tox_install.sh
  * Update translation setup
  * tempest: Add a comment
  * Updated from global requirements
  * tempest: Remove an extra comma, which breaks the following assertion
  * Add unittest of convert_action_to_case_insensitive
  * Updated from global requirements
  8.0.0.0b2
  * Clean up removed hacking rule from [flake8] ignore lists
  * tempest: Add test cases for router insertion
  * Replace deprecated library function os.popen() with subprocess
  * Add unit test for convert_protocol
  * Updated from global requirements
  * Change LOG.warn to LOG.warning
  * LOG.warn -> LOG.warning
  * Trival: Remove unused logging import
  * tempest: Update after the recent tempest change
  * Updated from global requirements
  * Avoid duplicating tenant check when creating resources
  * Fix a typo from UPPER_CONTRAINTS_FILE to UPPER_CONSTRAINTS_FILE
  * Setup for translation
  * Deprecated tox -downloadcache option removed
  * Remove Neutron FWaaS static example configuration files
  * Updated from global requirements
  * Added constraints tox targets
  * Adapt to the recent tempest
- Use oslo-config-generator to generate the sample config
- Adjust Requires
* Tue Dec  8 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0b2.dev11:
  * Automatically generate neutron FWaaS configuration files
  * Delete python bytecode before every test run
  * Fix db error when running python34 Unit tests
* Sun Dec  6 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0b2.dev6:
  * Updated from global requirements
  * Remove dependency on neutron for topics
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0b2.dev3:
  * Add reno for release notes management
* Fri Dec  4 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.0b2.dev1:
  * Remove version from setup.cfg
  8.0.0.0b1
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev49:
  * Fix TempestPlugin to fix gate failure
  * Add some more tempest scenarios
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev46:
  * Freescale FWaaS Plugin code final decomposition
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev45:
  * Updated from global requirements
  * Remove deprecated use_namespaces option
* Mon Nov 16 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev42:
  * Updated from global requirements
  * Move api tests from Neutron repository
* Fri Nov 13 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev38:
  * Set ZUUL_BRANCH using BRANCH if not available
  * Removed new=True argument from create_connection
* Fri Nov  6 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev35:
  * Revert "Register FWaaS resources to quota engine"
* Thu Nov  5 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev33:
  * Prepare neutron "use_namespaces" option removal
  * Update list of modules supporting py34 tests
  * Add tempest scenario tests
  * Register FWaaS resources to quota engine
* Wed Oct 28 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev25:
  * Include alembic versions directory to the package
* Tue Oct 27 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev23:
  * Updated from global requirements
* Mon Oct 26 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev21:
  * FWaaS fix comment typos
  7.0.0
  * Tag the alembic migration revisions for Liberty
  * Use stable/liberty branch for neutron dep
  7.0.0.0rc1
  * Update defaultbranch in .gitreview to stable/liberty
* Fri Oct 23 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev30:
  * Use assert(Not)In instead of assertTrue/False
* Wed Oct 21 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev28:
  * Updated from global requirements
* Sun Oct 18 2015 dmueller@suse.com
- fix fwaas driver default
* Fri Oct 16 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev27:
  * Updated from global requirements
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev26:
  * Updated from global requirements
  * Validate src_ip_adress, dest_ip_address and ip_version
  * Updated from global requirements
  * use assertIs(Not)None instead of assert(Not)Equal
  * use assertFalse instead of assertEqual(False, ***)
  * Fix argument order for assertEqual to (expected, observed)
  * Consume FWaaS plugin queue in RPC workers
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev13:
  * Case-Sensitivity for name column in fw table
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev12:
  * Kill HEADS file
* Thu Oct  1 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev10:
  * Tag the alembic migration revisions for Liberty
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev8:
  * Stop doing any magic cloning of neutron during CI
* Thu Sep 24 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-8.0.0.dev7:
  * Open Mitaka development
* Tue Sep 22 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b4.dev6:
  * Change ignore-errors to ignore_errors
* Mon Sep 21 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b4.dev5:
  * Updated from global requirements
  * Fix check_migration error
* Sun Sep 13 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b4.dev3:
  * Added +x permission to gate hook scripts
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b4.dev1:
  * py34 support for fwaas
  7.0.0.0b3
* Fri Sep  4 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev44:
  * Updated from global requirements
  * Removing unused dependency: discover
* Sun Aug 30 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev40:
  * Updated from global requirements
  * Kill contention between update and delete
  * FWaaS: Fix 500 INTERNAL error on too long name or description
  * Adopt the migration chaining and branch names from neutron
* Sat Aug 29 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev32:
  * Switch to using os-testr's copy of subunit2html
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev30:
  * Cisco CSR FWaaS driver should use 'l4-options' in CSR RESTAPI call
  * Add REJECT rule on Neutron FWaaS
* Thu Aug 27 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev26:
  * Updated from global requirements
  * Add oslotest dependency to test-requirements
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev23:
  * Reduce contention between update and delete
* Thu Aug 20 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev21:
  * Make tests/unit/extensions discoverable
* Wed Aug 19 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev19:
  * Updated from global requirements
* Sat Aug 15 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev18:
  * Updated from global requirements
  * Use oslo_log.helpers.log_method_call
* Fri Aug 14 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev15:
  * Validate tenant_id between firewall and firewall-policy
  * Do not make delete_db_firewall conditional
  * Remove quantum untracked files from .gitignore
  * Fix wrong argument name in _rpc_update_firewall
* Thu Aug 13 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev9:
  * Updated from global requirements
* Tue Aug 11 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev8:
  * switch to multi branch migration tree for liberty
  * Killed existing downgrade rules in migration scripts
  * script.py.mako: update to latest standards
* Thu Aug  6 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev3:
  * py34: Enable initial python34 testing for FWaaS
* Sat Aug  1 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b3.dev1:
  7.0.0.0b2
  * Register alembic_migrations at install time
  * Updated from global requirements
* Thu Jul 30 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b2.dev9:
  * py34: Fix usage of gettext.install
* Wed Jul 22 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b2.dev8:
  * Updated from global requirements
* Thu Jul  9 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b2.dev7:
  * Fix UT failures during firewall mock plugin setup
* Tue Jul  7 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b2.dev6:
  * COMMON_PREFIXES cleanup - patch 3/5
  * Updated from global requirements
  * Switch to oslo_utils.uuidutils
  * Fixes firewall going to error state on an update
* Fri Jun 26 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0b2.dev1:
  * Switch to oslo.service
  7.0.0.0b1
* Tue Jun 23 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0a1.dev7:
  * Updated from global requirements
  * Add handle for protocol value "any" in CSR1kv driver
* Sat Jun 20 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0a1.dev4:
  * Updated from global requirements
* Fri Jun 19 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0a1.dev2:
  * Trim some unused test packages
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-7.0.0.0a1.dev1:
  * Update version for Liberty
  7.0.0a0
* Fri Jun 12 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev25:
  * Updated from global requirements
  * Revert "Insert tenant_id validation for fw and fw-policy"
  * Updated from global requirements
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev20:
  * Enable random hash seeds
  * Do not assume jsonutils.dumps ordering
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev16:
  * Python 3: use six.iteritems instead of dict.items
* Wed May 27 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev15:
  2015.1.0
  * update .gitreview for stable/kilo
  * Updated Protocol named constants
  * Add Kilo release milestone
  * Pin neutron to stable/kilo
  * Restore Brocade Vyatta firewall functionality
* Fri May 22 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev27:
  * Updated from global requirements
  * Add validation of port_range for firewall-rule
* Wed May 20 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev23:
  * vendor code should refer to Brocade
* Sat May 16 2015 cloud-devel@suse.de
- Update to version neutron-fwaas-2015.2.0.dev21:
  * Remove contextlib.nested from tests
* Mon May 11 2015 dmueller@suse.com
- adjust config file
- remove -test subpackage
* Fri May  8 2015 tbechtold@suse.com
- Initial packaging after upstream split
